SendingMessageData class

Class for sending message

Constructors

SendingMessageData({required String createID, required V2TimMessage message, required int progress, required String sdkID, required bool isSendComplete})

Properties

createID → String
=== message created ID ===
final
hashCode → int
The hash code for this object.
no setterinherited
isSendComplete → bool
=== value if send message is completed ===
final
message → V2TimMessage
=== message ===
final
progress → int
=== progress ===
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdkID → String
=== sdk ID ===
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited