TencentCloudChatCallbacksTrigger class

Properties

callbacksList → List<TencentCloudChatCallbacks>
final
defaultV2TimSDKListener ↔ V2TimSDKListener?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCallback(TencentCloudChatCallbacks callbacks) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onSDKFailed(String apiName, int code, String desc) → void
onUserNotificationEvent(TencentCloudChatComponentsEnum component, TencentCloudChatUserNotificationEvent event) → void
removeAllCallbacks() → void
removeCallback(TencentCloudChatCallbacks callbacks) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

componentName ↔ String
getter/setter pair