TencentCloudChatComponentConfigs class

A class containing global configuration options for each modular UI component.

Constructors

TencentCloudChatComponentConfigs({TencentCloudChatMessageConfig? messageConfig, TencentCloudChatConversationConfig? conversationConfig, TencentCloudChatContactConfig? contactConfig, TencentCloudChatUserProfileConfig? userProfileConfig, TencentCloudChatGroupProfileConfig? groupProfileConfig})
Constructs a new instance of TencentCloudChatComponentConfigs with the specified configurations for each component.
const

Properties

contactConfig → TencentCloudChatContactConfig?
The configuration for the TencentCloudChatContact component.
final
conversationConfig → TencentCloudChatConversationConfig?
The configuration for the TencentCloudChatConversation component.
final
groupProfileConfig → TencentCloudChatGroupProfileConfig?
The configuration for the TencentCloudChatGroupProfile component.
final
hashCode → int
The hash code for this object.
no setterinherited
messageConfig → TencentCloudChatMessageConfig?
The configuration for the TencentCloudChatMessage component.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userProfileConfig → TencentCloudChatUserProfileConfig?
The configuration for the TencentCloudChatUserProfile component.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited