TencentCloudChatComponentControllers class

The controllers for events related to UI components for each modular UI component, can be used for all corresponding instance.

Constructors

TencentCloudChatComponentControllers({TencentCloudChatComponentBaseController? conversationController, TencentCloudChatComponentBaseController? messageController, TencentCloudChatComponentBaseController? contactController, TencentCloudChatComponentBaseController? userProfileController, TencentCloudChatComponentBaseController? groupProfileController})
Constructs a new instance of TencentCloudChatComponentControllers with the specified controllers for each component.
const

Properties

contactController → TencentCloudChatComponentBaseController?
Specify an instance of TencentCloudChatContactController for taking over control for all TencentCloudChatContact instances.
final
conversationController → TencentCloudChatComponentBaseController?
Specify an instance of TencentCloudChatConversationController for taking over control for all TencentCloudChatConversation instances.
final
groupProfileController → TencentCloudChatComponentBaseController?
Specify an instance of TencentCloudChatGroupProfileController for taking over control for all TencentCloudChatGroupProfile instances.
final
hashCode → int
The hash code for this object.
no setterinherited
messageController → TencentCloudChatComponentBaseController?
Specify an instance of TencentCloudChatMessageController for taking over control for all TencentCloudChatMessage instances.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userProfileController → TencentCloudChatComponentBaseController?
Specify an instance of TencentCloudChatUserProfileController for taking over control for all TencentCloudChatUserProfile instances.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited