V2TimUserFullInfo class

V2TimUserFullInfo

Constructors

V2TimUserFullInfo({String? userID, String? nickName, String? faceUrl, String? selfSignature, int? gender, int? allowType, Map<String, String>? customInfo, int? role, int? level, int? birthday})
V2TimUserFullInfo.fromJson(Map json)

Properties

allowType ↔ int?
getter/setter pair
birthday ↔ int?
getter/setter pair
customInfo ↔ Map<String, String>?
getter/setter pair
faceUrl ↔ String?
getter/setter pair
gender ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
level ↔ int?
getter/setter pair
nickName ↔ String?
getter/setter pair
role ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selfSignature ↔ String?
getter/setter pair
userID ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toLogString() → dynamic
toSetUserInfoParam() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited